#include "tools.h"
#include "comm/comm.h"
#include "comm/global/global.h"
#include "comm/mcomm/mcomm.h"

#ifndef __MPI
#define __MPI
extern int MPI_errno;

/*M
   MPI_infos - Determine the source process of a pending receive

   Synopsis:
   int MPI_infos()

   Returns:
   The source of the just received message.
M*/
#define MPI_infos() RECVFROM()

/*M
   MPI_infot - Determine the type of the last receive

   Synopsis:
   int MPI_infot()

   Returns:
   The source of the just received message.
M*/
#define MPI_infot() RECVTYPE()

/*M
  MPI_sync - Synchronize all processes 

  Synopsis:
  int sync
M*/
#define MPI_sync(gid) GSYNC((ProcSet *)gid)

#define MPI_AckType MSG_GLOBAL

/*M
  MPI_getid - Determine the group context PID of the calling process for
              a specified group id number.

  Input Parameter:
. gid - group id 

  Synopsis:
  int MPI_getid( gid )
  int gid;

  Returns:
  Relative process number of the calling process in the specified group.
M*/
#define MPI_getid(gid) PSMYPROCID((ProcSet *)gid)

/* This is just struct iovec renamed */
typedef struct {
    void *base;
    int  len;
    } MPI_DATAVEC;
typedef struct {
    void *base;
    int  len;
    int  datatype;
    } MPI_HDATAVEC;

typedef enum { _MPI_SEND, _MPI_RECV } _MPI_Kind;
typedef enum { _MPI_CONTIG, _MPI_STRIDE, _MPI_GENERAL } _MPI_Flavor;
typedef struct {
    void          *buf;
    int           type, len, partner;
    int           lenblk, stride, nblks;
    MSGBVEC       bv;
    _MPI_Kind     kind;
    _MPI_Flavor   flavor;
    ASYNCSendId_t  sid;
    ASYNCRecvId_t  rid;
    } _MPI_pendings;

#define _MPI_SEND  1
#define _MPI_RECV  2
#define _MPI_EMPTY 0

/* values of datatype */
#define MPI_INT    MSG_INT  
#define MPI_LONG   MSG_LNG  
#define MPI_FLOAT  MSG_FLT
#define MPI_DOUBLE MSG_DBL   
#define MPI_SHORT  MSG_SHRT  
#define MPI_BYTE   MSG_OTHER 

#endif



